/*
 * Copyright (C) 2026 UBports Foundation.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#pragma once

#include <QJsonObject>
#include <lomiri/storage/provider/Item.h>

#include <string>

bool stat_exists(QJsonObject const& result);
std::string make_etag(QJsonObject const& entry);
lomiri::storage::provider::Item make_item(
    QJsonObject const& entry, std::string const& id, bool infer_child = false);
lomiri::storage::provider::Item make_root_item(QJsonObject const& item);
